@@ -10,8 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-import six
+from unittest import mock
+
 import testscenarios
 import testtools
 import yaml
@@ -105,4 +105,4 @@ but very:
   - incorrect
 """
         ex = self.assertRaises(ValueError, environment_format.parse, yaml)
-        self.assertIn('but very:\n            ^', six.text_type(ex))
+        self.assertIn('but very:\n            ^', str(ex))
