@@ -12,99 +12,110 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from mox3 import mox
-from six.moves.urllib import parse
+from unittest import mock
+
 import testtools
+from urllib import parse
 
 from heatclient.common import utils
 from heatclient.v1 import resources
 
 
+class FakeAPI(object):
+    """Fake API and ensure request url is correct."""
+
+    def __init__(self, expect, key):
+        self.expect = expect
+        self.key = key
+
+    def get(self, *args, **kwargs):
+        assert ('GET', args[0]) == self.expect
+
+    def json_request(self, *args, **kwargs):
+        assert args == self.expect
+        ret = self.key and {self.key: []} or {}
+        return {}, {self.key: ret}
+
+    def raw_request(self, *args, **kwargs):
+        assert args == self.expect
+        return {}
+
+    def head(self, url, **kwargs):
+        return self.json_request("HEAD", url, **kwargs)
+
+    def post(self, url, **kwargs):
+        return self.json_request("POST", url, **kwargs)
+
+    def put(self, url, **kwargs):
+        return self.json_request("PUT", url, **kwargs)
+
+    def delete(self, url, **kwargs):
+        return self.raw_request("DELETE", url, **kwargs)
+
+    def patch(self, url, **kwargs):
+        return self.json_request("PATCH", url, **kwargs)
+
+
 class ResourceManagerTest(testtools.TestCase):
 
-    def setUp(self):
-        super(ResourceManagerTest, self).setUp()
-        self.m = mox.Mox()
-        self.addCleanup(self.m.UnsetStubs)
+    def _base_test(self, func, fields, expect, key):
+        manager = resources.ResourceManager(FakeAPI(expect, key))
 
-    def _base_test(self, expect, key):
+        with mock.patch.object(manager, '_resolve_stack_id') as mock_rslv, \
+                mock.patch.object(utils, 'get_response_body') as mock_resp:
+            mock_resp.return_value = {key: key and {key: []} or {}}
+            mock_rslv.return_value = 'teststack/abcd1234'
 
-        class FakeAPI(object):
-            """Fake API and ensure request url is correct."""
+            getattr(manager, func)(**fields)
 
-            def get(self, *args, **kwargs):
-                assert ('GET', args[0]) == expect
-
-            def json_request(self, *args, **kwargs):
-                assert args == expect
-                ret = key and {key: []} or {}
-                return {}, {key: ret}
-
-            def raw_request(self, *args, **kwargs):
-                assert args == expect
-                return {}
-
-            def head(self, url, **kwargs):
-                return self.json_request("HEAD", url, **kwargs)
-
-            def post(self, url, **kwargs):
-                return self.json_request("POST", url, **kwargs)
-
-            def put(self, url, **kwargs):
-                return self.json_request("PUT", url, **kwargs)
-
-            def delete(self, url, **kwargs):
-                return self.raw_request("DELETE", url, **kwargs)
-
-            def patch(self, url, **kwargs):
-                return self.json_request("PATCH", url, **kwargs)
-
-        manager = resources.ResourceManager(FakeAPI())
-        self.m.StubOutWithMock(manager, '_resolve_stack_id')
-        self.m.StubOutWithMock(utils, 'get_response_body')
-        utils.get_response_body(mox.IgnoreArg()).AndReturn(
-            {key: key and {key: []} or {}})
-        manager._resolve_stack_id('teststack').AndReturn('teststack/abcd1234')
-        self.m.ReplayAll()
-
-        return manager
+            mock_resp.assert_called_once_with(mock.ANY)
+            mock_rslv.assert_called_once_with('teststack')
 
     def test_get(self):
         fields = {'stack_id': 'teststack',
                   'resource_name': 'testresource'}
         expect = ('GET',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/testresource')
         key = 'resource'
 
-        manager = self._base_test(expect, key)
-        manager.get(**fields)
-        self.m.VerifyAll()
+        self._base_test('get', fields, expect, key)
 
     def test_get_with_attr(self):
         fields = {'stack_id': 'teststack',
                   'resource_name': 'testresource',
                   'with_attr': ['attr_a', 'attr_b']}
         expect = ('GET',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/testresource?with_attr=attr_a&with_attr=attr_b')
         key = 'resource'
 
-        manager = self._base_test(expect, key)
-        manager.get(**fields)
-        self.m.VerifyAll()
+        self._base_test('get', fields, expect, key)
 
     def test_get_with_unicode_resource_name(self):
         fields = {'stack_id': 'teststack',
                   'resource_name': u'\u5de5\u4f5c'}
         expect = ('GET',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/%E5%B7%A5%E4%BD%9C')
         key = 'resource'
 
-        manager = self._base_test(expect, key)
-        manager.get(**fields)
-        self.m.VerifyAll()
+        self._base_test('get', fields, expect, key)
+
+    def _test_list(self, fields, expect):
+        key = 'resources'
+
+        class FakeResponse(object):
+            def json(self):
+                return {key: {}}
+
+        class FakeClient(object):
+            def get(self, *args, **kwargs):
+                assert args[0] == expect
+                return FakeResponse()
+
+        manager = resources.ResourceManager(FakeClient())
+        manager.list(**fields)
 
     def test_list(self):
         self._test_list(
@@ -135,32 +146,15 @@ class ResourceManagerTest(testtools.TestCase):
             }, True)
         )
 
-    def _test_list(self, fields, expect):
-        key = 'resources'
-
-        class FakeResponse(object):
-            def json(self):
-                return {key: {}}
-
-        class FakeClient(object):
-            def get(self, *args, **kwargs):
-                assert args[0] == expect
-                return FakeResponse()
-
-        manager = resources.ResourceManager(FakeClient())
-        manager.list(**fields)
-
     def test_metadata(self):
         fields = {'stack_id': 'teststack',
                   'resource_name': 'testresource'}
         expect = ('GET',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/testresource/metadata')
         key = 'metadata'
 
-        manager = self._base_test(expect, key)
-        manager.metadata(**fields)
-        self.m.VerifyAll()
+        self._base_test('metadata', fields, expect, key)
 
     def test_generate_template(self):
         fields = {'resource_name': 'testresource'}
@@ -179,26 +173,24 @@ class ResourceManagerTest(testtools.TestCase):
                 return {}, {key: ret}
 
         manager = resources.ResourceManager(FakeAPI())
-        self.m.StubOutWithMock(utils, 'get_response_body')
-        utils.get_response_body(mox.IgnoreArg()).AndReturn(
-            {key: key and {key: []} or {}})
-        self.m.ReplayAll()
 
-        manager.generate_template(**fields)
-        self.m.VerifyAll()
+        with mock.patch.object(utils, 'get_response_body') as mock_resp:
+            mock_resp.return_value = {key: key and {key: []} or {}}
+
+            manager.generate_template(**fields)
+
+            mock_resp.assert_called_once_with(mock.ANY)
 
     def test_signal(self):
         fields = {'stack_id': 'teststack',
                   'resource_name': 'testresource',
                   'data': 'Some content'}
         expect = ('POST',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/testresource/signal')
         key = 'signal'
 
-        manager = self._base_test(expect, key)
-        manager.signal(**fields)
-        self.m.VerifyAll()
+        self._base_test('signal', fields, expect, key)
 
     def test_mark_unhealthy(self):
         fields = {'stack_id': 'teststack',
@@ -206,13 +198,11 @@ class ResourceManagerTest(testtools.TestCase):
                   'mark_unhealthy': 'True',
                   'resource_status_reason': 'Anything'}
         expect = ('PATCH',
-                  '/stacks/teststack%2Fabcd1234/resources'
+                  '/stacks/teststack/abcd1234/resources'
                   '/testresource')
         key = 'mark_unhealthy'
 
-        manager = self._base_test(expect, key)
-        manager.mark_unhealthy(**fields)
-        self.m.VerifyAll()
+        self._base_test('mark_unhealthy', fields, expect, key)
 
 
 class ResourceStackNameTest(testtools.TestCase):
